xwd2stiff(1)

xwd2stiff - convert an X Window Dump (XWD) image file to Stream TIFF (STIFF)

As shipped in IRIX 6.5.30. Unchanged since IRIX 6.5.

NAME
     xwd2stiff - convert an X Window Dump (XWD) image file to Stream TIFF
     (STIFF)

SYNOPSIS
     xwd2stiff [-O filename] [-L filename]
               [-c] [-h] [-D] [XWDFilename ...]

DESCRIPTION
     xwd2stiff converts X Window Dump image files into Stream TIFF (STIFF)
     format.

     By default, xwd2stiff reads its input image from the standard input,
     writes its output to the standard output and sends messages to standard
     error. If one or more image files are specified on the command line,
     xwd2stiff reads input from these files rather than the standard input.

     -O filename
               Specifies the name of the file to which the STIFF output will
               be sent.  If the -O option is not specified, output will be
               sent to the standard output.

     -L filename
               Specifies the name of the file to which error, warning and
               informational messages are to be written. If the file specified
               already exists, any messages generated by xwd2stiff will be
               appended to the end of the file.  If the -L option is not
               specified, message output will be sent to standard error.

     -c        XWD images created under a DirectColor visual often have an
               incorrect colormap stored in the image. Typically the image
               data itself is correct and can be converted properly without
               reference to the colormap.  By default, xwd2stiff does not
               reference the colormap when converting an XWD image created
               with a DirectColor visual. Specifying the -c option forces
               xwd2stiff to use the colormap stored in the image when
               converting a DirectColor image.  The -c option effects the use
               of the colormap only for DirectColor images.

     -h        Prints a program usage message to the standard error. This
               usage message also lists the currently supported output
               configurations.

     -D        Specifies verbose output for debugging purposes.

NOTES
     1.   xwd2stiff supports conversion of X11 XWD format files. X10 XWD files
          are not supported.

     2.   xwd2stiff supports conversion of a wide variety of XWD images. The
          program supports images saved under the StaticGray, GrayScale,
          StaticColor, PseudoColor, TrueColor and DirectColor visuals. Images
          may be 1, 2, 4, 8, 12 or 24 bits deep and may be in either MSBFirst
          or LSBFIrst byte and bit order. The image may be in XYBitmap,
          XYPixmap or ZPixmap format.

     3.   Images stored under the GrayScale, StaticColor or PseudoColor visual
          must contain a colormap. If the colormap is not present, the image
          will not be converted. DirectColor images must contain a colormap
          only if the -c option is specified. If a StaticGray image does not
          contain a colormap, a linear gray ramp will be used.

     4.   Due to processing overhead within Xlib, the conversion of images in
          the XYPixmap format is slow in comparison to the other formats. This
          is caused by the manner in which X organizes the image data. The
          XYPixmap format should be avoided in favor of the ZPixmap format.

     5.   If xwd2stiff is given an unrecognized or incomplete command line
          option switch, it will print a warning message to the standard
          error, ignore the option and continue processing.

FILES
     /usr/lib/print/xwd2stiff    Program file

SEE ALSO
     xwd(1), xwud(1), stiff2ps(1), psrip(1)